import threading

import xbmc
import requests
from resources.lib.modules import control, constants
from resources.lib.modules.log_utils import log

try:
    # Python3
    from http.server import BaseHTTPRequestHandler, HTTPServer
    from socketserver import ThreadingMixIn
    from urllib.parse import urlparse, parse_qs
except:
    # Python2
    from BaseHTTPServer import BaseHTTPRequestHandler, HTTPServer
    from SocketServer import ThreadingMixIn
    from urlparse import urlparse, parse_qs

HOST = '127.0.0.1'
PORT = 48444
REMOVE_IN_HEADERS = ['upgrade', 'host']
REMOVE_OUT_HEADERS = ['date', 'server', 'transfer-encoding', 'keep-alive', 'connection', 'content-length', 'content-encoding']

class RequestHandler(BaseHTTPRequestHandler):
    def log_message(self, format, *args):
        return

    def do_POST(self):
        self.send_error(404)

    def do_HEAD(self):
        self.send_error(404)

    def do_GET(self):
        #log(self.path)
        headers = {}
        for key in self.headers:
            if key.lower() not in REMOVE_IN_HEADERS:
                headers[key] = self.headers[key]
        origin_url = 'https:/'+self.path
        inxqs_quality=origin_url.find('?quality=')
        if inxqs_quality>0:
            origin_url=origin_url[0:inxqs_quality]
            #log('REMOVE QUALITY QS')
            #log(origin_url)

        response = requests.get(origin_url, headers=headers, timeout=5)

        self.send_response(response.status_code)

        for key in response.headers:
            if key.lower() not in REMOVE_OUT_HEADERS:
                self.send_header(key, response.headers[key])

        self.end_headers()

        ## Edit the content
        if self.path.endswith('.m3u8'):
            content = response.content.decode('utf8')
            if '?quality=' in self.path:
                #log('quality FOUND')
                url = urlparse(self.path)
                query = parse_qs(url.query)
                qualitym3u8 = query["quality"][0]
                #log(qualitym3u8)
                if qualitym3u8!='auto':
                    listqual = content.splitlines()
                    rememberinfoline = ''
                    savequalitylist = []
                    for l in listqual:
                        if 'RESOLUTION' in l:
                            rememberinfoline = l
                        elif '.m3u8' in l:
                            if l == qualitym3u8:
                                savequalitylist.append(rememberinfoline)
                                savequalitylist.append(l)
                        else:
                            savequalitylist.append(l)
                    content="\n".join(savequalitylist)+"\n"
                    #log("NEW CONTENT:")
                    #log(content)

            #Part 2. The Full stream list           
            nhldec= control.setting('nhl_decrypt_server')
            nhl66dec= control.setting('nhl66_decrypt_api')
            #content = content.replace('mf.svc.nhl.com','api.nhl66.ir/api/get_key_url')
            content = content.replace(nhldec,nhl66dec)
            self.wfile.write(content.encode('utf8'))
        else:
            self.wfile.write(response.content)
        

class ThreadedHTTPServer(ThreadingMixIn, HTTPServer):
    daemon_threads = True

def main():
    server = ThreadedHTTPServer((HOST, PORT), RequestHandler)
    server.allow_reuse_address = True
    httpd_thread = threading.Thread(target=server.serve_forever)
    httpd_thread.start()

    xbmc.Monitor().waitForAbort()

    server.shutdown()
    server.server_close()
    server.socket.close()
    httpd_thread.join()
